package pdd

import (
	"duoduo/conf"
	"duoduo/models/mysql"
	"duoduo/models/pdd"
	"duoduo/tools"
	"duoduo/tools/app"
	"fmt"
	"github.com/gin-gonic/gin"
	"github.com/shopspring/decimal"
	"time"
)

func PddDdkOrderListIncrementGet(c *gin.Context) {
	var inData pdd.PddDdkOrderListIncrementGetRequest
	var outData pdd.PddDdkOrderListIncrementGetResponse
	var pddErr pdd.ErrorPddResponse
	var sqlData mysql.Order
	var pag int

	confIni, err := conf.ConnIni()
	if err != nil {
		app.Error(c, 400, err, err.Error())
		return
	}

	err = c.ShouldBindJSON(&inData)
	if err != nil {
		app.Error(c, 400, err, err.Error())
		return
	}
	pag = 0
	for {
		pag++
		inData.ClientId = confIni.MustValue("pdd", "client_id")
		inData.Type = "pdd.ddk.order.list.increment.get"
		inData.Timestamp = fmt.Sprintf("%d", time.Now().Unix())
		inData.DataType = "JSON"
		inData.Page = fmt.Sprintf("%d", pag)
		inData.PageSize = "50"

		startTm, _ := tools.GetTimeStamp(inData.StartUpdateTime)
		inData.StartUpdateTime = fmt.Sprintf("%d", startTm)

		endTm, _ := tools.GetTimeStamp(inData.EndUpdateTime)
		inData.EndUpdateTime = fmt.Sprintf("%d", endTm)

		inData.Sign = "sign"
		sign, err := DDKSign(inData)
		if err != nil {
			app.Error(c, 400, err, err.Error())
			return
		}
		inData.Sign = sign
		val, err := PostDDk(inData, nil)

		if err != nil {
			app.Error(c, 400, err, err.Error())
			return
		}

		err = tools.JsonUnmarshal(val, &pddErr)
		if err != nil {
			app.Error(c, 500, err, err.Error())
			return
		}

		err = tools.JsonUnmarshal(val, &outData)
		if err != nil {
			app.Error(c, 500, nil, err.Error())
			return
		}

		if pddErr.ErrorResponse.ErrorCode != 0 {
			app.Error(c, 500, nil, pddErr.ErrorResponse.SubMsg)
			return
		}

		//同步订单信息
		for i := 0; i < len(outData.OrderListGetResponse.OrderList); i++ {

			var pid mysql.Pid
			var order mysql.Order
			var trans mysql.TransRecords

			sqlData.OrderID = outData.OrderListGetResponse.OrderList[i].OrderID
			sqlData.PID = outData.OrderListGetResponse.OrderList[i].PID
			sqlData.UpdateTime = tools.GetCurrntTimeStr()
			sqlData.OrderStatus = outData.OrderListGetResponse.OrderList[i].OrderStatus
			sqlData.GoodsName = outData.OrderListGetResponse.OrderList[i].GoodsName
			sqlData.GoodsThumbnailURL = outData.OrderListGetResponse.OrderList[i].GoodsThumbnailURL
			sqlData.OrderGroupSuccessTime = tools.TimeToStr(outData.OrderListGetResponse.OrderList[i].OrderGroupSuccessTime)
			sqlData.OrderStatusDesc = outData.OrderListGetResponse.OrderList[i].OrderStatusDesc
			sqlData.PromotionAmount = outData.OrderListGetResponse.OrderList[i].PromotionAmount
			sqlData.JSONData, _ = tools.JsonMarshal(&outData.OrderListGetResponse.OrderList[i])
			sqlData.OrderCreateTime = tools.TimeToStr(outData.OrderListGetResponse.OrderList[i].OrderCreateTime)
			sqlData.OrderSn = outData.OrderListGetResponse.OrderList[i].OrderSn
			sqlData.Amount = decimal.NewFromInt(outData.OrderListGetResponse.OrderList[i].PromotionAmount).Mul(decimal.NewFromFloat(0.006))
			sqlData.Amount1 = decimal.NewFromInt(outData.OrderListGetResponse.OrderList[i].PromotionAmount).Mul(decimal.NewFromFloat(0.001))
			sqlData.Amount2 = decimal.NewFromInt(outData.OrderListGetResponse.OrderList[i].PromotionAmount).Mul(decimal.NewFromFloat(0.001))
			sqlData.OrderAmount = decimal.NewFromInt(outData.OrderListGetResponse.OrderList[i].OrderAmount).Div(decimal.NewFromInt(100))

			fmt.Println("amount = ", sqlData.Amount)

			count := sqlData.GetNum()
			if count <= 0 {
				sqlData.CreateTime = tools.GetCurrntTimeStr()
				_, err = sqlData.Create()
				if err != nil {
					app.Error(c, 500, nil, err.Error())
					return
				}
			} else {
				_, err = sqlData.Update(sqlData.OrderID)
				if err != nil {
					app.Error(c, 500, nil, err.Error())
					return
				}
			}

			//统计钱包数据
			//首先获取open_id
			pid.Pid = outData.OrderListGetResponse.OrderList[i].PID
			pidVal, err := pid.GetOpenId()
			if err != nil {
				continue
			}
			order.PID = outData.OrderListGetResponse.OrderList[i].PID
			//统计钱包数据
			walletVal, err := order.GetAmount()
			if err != nil {
				continue
			}

			walletVal.LatelyAmount = walletVal.LatelyAmount.Div(decimal.NewFromInt(100)).Mul(decimal.NewFromFloat(0.6)).Round(2)
			walletVal.TodayAmount = walletVal.TodayAmount.Div(decimal.NewFromInt(100)).Mul(decimal.NewFromFloat(0.6)).Round(2)
			walletVal.TotalAmount = walletVal.TotalAmount.Div(decimal.NewFromInt(100)).Mul(decimal.NewFromFloat(0.6)).Round(2)
			walletVal.YesterdayAmount = walletVal.YesterdayAmount.Div(decimal.NewFromInt(100)).Mul(decimal.NewFromFloat(0.6)).Round(2)
			walletVal.AvailableAmount = walletVal.AvailableAmount.Div(decimal.NewFromInt(100)).Mul(decimal.NewFromFloat(0.6)).Round(2)

			trans.TransStatus = 3
			trans.OpenID = pidVal.OpenID
			transVal, err := trans.GetAmount()
			if err != nil {
				continue
			}
			walletVal.WithdrawalAmount = transVal.Amount.Div(decimal.NewFromInt(100)).Mul(decimal.NewFromFloat(0.6)).Round(2)
			walletVal.AvailableAmount = walletVal.AvailableAmount.Sub(walletVal.WithdrawalAmount).Mul(decimal.NewFromFloat(0.6)).Round(2)

			//更新钱包
			walletVal.OpenID = pidVal.OpenID
			walletVal.Pid = outData.OrderListGetResponse.OrderList[i].PID
			walletVal.UpdateTime = tools.GetCurrntTimeStr()
			_, err = walletVal.UpdateAll()
			if err != nil {
				continue
			}

		}

		if outData.OrderListGetResponse.TotalCount < 50 {
			break
		}
	}

	app.OK(c, nil, app.Success)
}
